@@ -486,31 +486,31 @@ def get_data(file_path, **kwargs):
     file_path = strUtils.format.file_path(file_path)
     exclude = obj.get_kwarg(['exclude'], [], (list, str), **kwargs)
     if exists(file_path):
-        print(f"file exists: {file_path}")
-    try:
-        file_data = {}
-        file_data['file_name'] = os.path.basename(file_path)
-        # ext = os.path.splitext(file_data['file_name'])
-        file_data['extension'] = get_ext(file_path)
-        file_data['name_no_ext'] = get_name_no_ext(file_path)
-        file_data['file_path'] = file_path
+        # print(f"file exists: {file_path}")
+        try:
+            file_data = {}
+            file_data['file_name'] = os.path.basename(file_path)
+            # ext = os.path.splitext(file_data['file_name'])
+            file_data['extension'] = get_ext(file_path)
+            file_data['name_no_ext'] = get_name_no_ext(file_path)
+            file_data['file_path'] = file_path
 
-        if 'dir_path' not in exclude:
-            file_data['dir_path'] = os.path.dirname(file_path)
-        if 'access_time' not in exclude:
-            file_data['access_time'] = get_access_time(file_path)
-        if 'modified_time' not in exclude:
-            file_data['modified_time'] = get_modified_time(file_path)
-        if 'created_time' not in exclude:
-            file_data['created_time'] = get_create_time(file_path)
-        if 'size' not in exclude:
-            file_data['size'] = os.path.getsize(file_path)
+            if 'dir_path' not in exclude:
+                file_data['dir_path'] = os.path.dirname(file_path)
+            if 'access_time' not in exclude:
+                file_data['access_time'] = get_access_time(file_path)
+            if 'modified_time' not in exclude:
+                file_data['modified_time'] = get_modified_time(file_path)
+            if 'created_time' not in exclude:
+                file_data['created_time'] = get_create_time(file_path)
+            if 'size' not in exclude:
+                file_data['size'] = os.path.getsize(file_path)
 
-        return file_data
-    except FileNotFoundError as error:
-        logger.warning(f"Error: {error}")
-        logger.warning(f"Failed to find the file: {file_path}")
-        return None
+            return file_data
+        except FileNotFoundError as error:
+            logger.warning(f"Error: {error}")
+            logger.warning(f"Failed to find the file: {file_path}")
+            return None
 
 
 def get_modified_time(file_path):
